==> groonga-6.0.4-x64.zip: groonga-6.0.4-x64/include/groonga/groonga.h <==
/*
  Copyright(C) 2014-2016 Brazil

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#pragma once

#include "groonga/portability.h"
#include "groonga/groonga.h"

#include "groonga/array.h"
#include "groonga/config.h"
#include "groonga/dat.h"
#include "groonga/db.h"
#include "groonga/dump.h"
#include "groonga/expr.h"
#include "groonga/file_reader.h"
#include "groonga/geo.h"
#include "groonga/hash.h"
#include "groonga/ii.h"
#include "groonga/obj.h"
#include "groonga/operator.h"
#include "groonga/output.h"
#include "groonga/pat.h"
#include "groonga/request_canceler.h"
#include "groonga/request_timer.h"
#include "groonga/table.h"
#include "groonga/thread.h"
#include "groonga/time.h"
#include "groonga/type.h"
#include "groonga/util.h"
#include "groonga/window_function.h"
#include "groonga/windows.h"
#include "groonga/windows_event_logger.h"

==> groonga-7.0.2-x64.zip: groonga-7.0.2-x64/include/groonga/groonga.h <==
/*
  Copyright(C) 2014-2017 Brazil

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#pragma once

#include "groonga/portability.h"
#include "groonga/groonga.h"

#include "groonga/accessor.h"
#include "groonga/array.h"
#include "groonga/cache.h"
#include "groonga/column.h"
#include "groonga/config.h"
#include "groonga/dat.h"
#include "groonga/db.h"
#include "groonga/dump.h"
#include "groonga/error.h"
#include "groonga/expr.h"
#include "groonga/file_reader.h"
#include "groonga/geo.h"
#include "groonga/hash.h"
#include "groonga/id.h"
#include "groonga/ii.h"
#include "groonga/obj.h"
#include "groonga/operator.h"
#include "groonga/output.h"
#include "groonga/pat.h"
#include "groonga/request_canceler.h"
#include "groonga/request_timer.h"
#include "groonga/table.h"
#include "groonga/thread.h"
#include "groonga/time.h"
#include "groonga/type.h"
#include "groonga/util.h"
#include "groonga/window_function.h"
#include "groonga/windows.h"
#include "groonga/windows_event_logger.h"
